<?php $TRANSLATIONS = array(
"Export this ownCloud instance" => "Exportar esta instancia de ownCloud",
"This will create a compressed file that contains the data of this owncloud instance." => "Se creará un archivo comprimido que contendrá los datos de esta instancia de ownCloud.",
"Please choose the export type:" => "Elegí cómo querés exportar:",
"ownCloud system files" => "Archivos de sistema de ownCloud",
"Just user files" => "Solamente los archivos de usuario",
"Export" => "Exportar"
);
